@@ -1,5 +1,5 @@
 //// File Name: cdm_rcpp_gdd.cpp
-//// File Version: 3.14
+//// File Version: 3.151
 
 
 
@@ -32,12 +32,12 @@ Rcpp::List cdm_rcpp_generalized_distance_method( Rcpp::NumericMatrix data,
             for (int ii=0; ii<I; ii++){   //  begin item ii
                 if ( dataresp(nn,ii)==1 ){
                     //*** data=1 and idealresp=0
-                    if ( ( data(nn,ii) == 1 ) & ( idealresp(ii,ll) == 0 ) ){
+                    if ( ( data(nn,ii) == 1 ) && ( idealresp(ii,ll) == 0 ) ){
                         //     1 - P0  = P1
                         dist(nn,ll) += std::pow( 1 + std::exp( - ( b[ii] + a[ii] * theta[nn] ) ), -1 );
                     }
                     //*** data=0 and idealresp=1
-                    if ( ( data(nn,ii) == 0 ) & ( idealresp(ii,ll) == 1 ) ){
+                    if ( ( data(nn,ii) == 0 ) && ( idealresp(ii,ll) == 1 ) ){
                         //     1 - P1  = P0
                         dist(nn,ll) += std::pow( 1 + std::exp( ( b[ii] + a[ii] * theta[nn] ) ), -1 );
                     }
